@@ -18,3 +18,8 @@ from . import commonInputOutput as iostd
 from . import physicsConstants as cst
 from . import glob_colors  as colors
 from .glob_colors import *
+
+def funcs(obj):
+    import inspect
+    functions = '\n'.join([f[0] for f in inspect.getmembers(obj,predicate=inspect.isfunction)])
+    print(functions)
